package com.ruoyi.web.projectInfo.mapper;

import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

@Repository
public interface WxProjectInfoMapper {

    //查询出人员类型信息
    List<String> getPostIdByUserId(String userId);
    //查询组织架构下一层级
    List<Map<String, Object>> getDeptSubordinate(Map<String,Object> map);
    //查询区级层级
    List<Map<String, Object>> getQUDeptSubordinate(Map<String,Object> map);
    ///根据组织架构id查询数据
    Map<String,Object> getDeptData(String deptId);
    //查询出项目用户公司项目信息
    Map<String,Object> getCompanyAndProjectByUserId(String userId);
    //查询所有省级
    List<Map<String,Object>> getShengList(Map<String,Object> map);
    //根据所选层级或者公司查询登录用户的项目
    List<Map<String,Object>> getProjectByDeptIdAndCompanyId(Map<String,Object> map);
    //根据登录账号查询出企业信息
    Map<String,Object> getCompanyByUserId(Map<String,Object> map);
    //企业人员根据组织架构查询出公司列表
    List<Map<String,Object>> getCompanyQY(Map<String,Object> map);
    //根据公司id查询出公司名称
    Map<String,Object> getCompanyInfo(String superiorCompany);
    //监管人员根据组织架构查询出公司列表
    List<Map<String,Object>> getCompanyJG(Map<String,Object> map);
    //根据总公司层级查询出集团公司列表
    List<Map<String,Object>> getCompanySonData(Map<String,Object> map);
    //查询上一级公司
    Map<String,Object> getNextLevelCompany(Map<String,Object> map);


    /**
      * Methods
      * @describe 描述：查询项目的经度纬度列表
      * @author 作者：Makalu
      * @date 时间：2020/7/7 15:48
      * @version 版本： V1.0
      * @param deptId：String
      * @return 返回值：list
      * @throws Exception 异常：none
      */
    public List<Map<String, Object>> selectProjectPoint(String deptId);

    /**
     * Methods
     * @describe 描述：查询建设单位下的项目个数
     * @author 作者：Makalu
     * @date 时间：2020/7/7 15:44
     * @version 版本： V1.0
     * @param deptId：map
     * @return 返回值：int
     * @throws Exception 异常：none
     */
    public int selectProjectSize(String deptId);

    /**
      * Methods
      * @describe 描述：查询项目的基本信息
      * @author 作者：Makalu
      * @date 时间：2020/7/7 10:57
      * @version 版本： V1.0
      * @param map：map
      * @return 返回值：list
      * @throws Exception 异常：none
      */
    public List<Map<String, Object>> selectProjectInfo(Map<String,Object> map);

    /**
      * Methods
      * @describe 描述：查询项目的概况信息
      * @author 作者：Makalu
      * @date 时间：2020/7/7 16:21
      * @version 版本： V1.0
      * @param id：String
      * @return 返回值：map
      * @throws Exception 异常：none
      */
    public Map<String, Object> selectProjectOverview(String id);

    /**
      * Methods
      * @describe 描述：查询项目的管理概况
      * @author 作者：Makalu
      * @date 时间：2020/7/7 16:37
      * @version 版本： V1.0
      * @param id：String
      * @return 返回值：map
      * @throws Exception 异常：none
      */
    public Map<String, Object> selectProjectManage(String id);

    /**
     * 模糊查询项目信息
     * @param map
     * @return
     */
    List<Map<String,Object>>  getProjectInfoByName(Map<String,Object> map);

    /**
     * 模糊查询出预警项目
     * @param map
     * @return
     */
    List<Map<String,Object>> getProjectInfoEnviron(Map<String,Object> map);

    List<Map<String,Object>> getChinaProvince();

    int addChinaCity(List<Map<String,Object>> list);

    /*********************************小程序首页新逻辑**************************************/

    /**
     * 查询项目相关信息
     * @param projectId
     * @return
     */
    Map<String,Object> getProjectAndChinaData(String projectId);

    /**
     * 查询公司信息
     * @return
     */
    Map<String,Object> getDeptInfo();

    /**
     * 查询公司信息
     * @param map
     * @return
     */
    Map<String,Object> getDeptInfoByMap(Map<String,Object> map);

    /**
     * 查询出省份信息
     * @param deptId
     * @return
     */
    List<Map<String,Object>> getChinaProvinceList(Map<String,Object> deptId);

    /**
     * 获取公司下一层级
     * @param map
     * @return
     */
    List<Map<String,Object>> getDeptIdNext(Map<String,Object> map);

    /**
     * 获取建设单位
     * @param projectId
     * @return
     */
    List<Map<String,Object>> getProjectUnitList(String projectId);

    /**
     * 查询子公司信息
     * @param map
     * @return
     */
    List<Map<String,Object>>  getZGSDeptInfoByMap(Map<String,Object> map);

    /**
     * 获取建设单位
     * @param projectId
     * @return
     */
    Map<String,Object> selectDeptByProjectId(Long projectId);

    /**
     * 获取建设单位
     * @param userName
     * @return
     */
    Map<String,Object> selectDeptByUserName(String userName);

}
