package com.yanzhu.jh.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.project.domain.SurProjectInvest;
import com.yanzhu.jh.project.service.ISurProjectInvestService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目投资Controller
 * 
 * @author JiangYuQi
 * @date 2023-07-29
 */
@RestController
@RequestMapping("/project/surPorjectInvest")
public class SurProjectInvestController extends BaseController
{
    @Autowired
    private ISurProjectInvestService surProjectInvestService;

    /**
     * 查询项目投资列表
     */
    @PreAuthorize("@ss.hasPermi('project:surPorjectInvest:list')")
    @GetMapping("/list")
    public TableDataInfo list(SurProjectInvest surProjectInvest)
    {
        startPage();
        List<SurProjectInvest> list = surProjectInvestService.selectSurProjectInvestList(surProjectInvest);
        return getDataTable(list);
    }

    /**
     * 导出项目投资列表
     */
    @PreAuthorize("@ss.hasPermi('project:surPorjectInvest:export')")
    @Log(title = "项目投资", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SurProjectInvest surProjectInvest)
    {
        List<SurProjectInvest> list = surProjectInvestService.selectSurProjectInvestList(surProjectInvest);
        ExcelUtil<SurProjectInvest> util = new ExcelUtil<SurProjectInvest>(SurProjectInvest.class);
        util.exportExcel(response, list, "项目投资数据");
    }

    /**
     * 获取项目投资详细信息
     */
    @PreAuthorize("@ss.hasPermi('project:surPorjectInvest:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectInvestService.selectSurProjectInvestById(id));
    }

    /**
     * 新增项目投资
     */
    @PreAuthorize("@ss.hasPermi('project:surPorjectInvest:add')")
    @Log(title = "项目投资", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SurProjectInvest surProjectInvest)
    {
        return toAjax(surProjectInvestService.insertSurProjectInvest(surProjectInvest));
    }

    /**
     * 修改项目投资
     */
    @PreAuthorize("@ss.hasPermi('project:surPorjectInvest:edit')")
    @Log(title = "项目投资", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurProjectInvest surProjectInvest)
    {
        return toAjax(surProjectInvestService.updateSurProjectInvest(surProjectInvest));
    }

    /**
     * 删除项目投资
     */
    @PreAuthorize("@ss.hasPermi('project:surPorjectInvest:remove')")
    @Log(title = "项目投资", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectInvestService.deleteSurProjectInvestByIds(ids));
    }
}
